@@ -193,7 +193,7 @@ class Wsdl(WsdlBase):
                         'update.cl_update_eixupdate_force',
                         'cl_builder_rebuild_changed_set',
                         'cl_builder_rebuilt_binaries_set',
-                        'update.cl_update_skip_rb_set',
+                        'update.cl_update_revdep_rebuild_set',
                         'update.cl_update_onedepth_set',
                         'update.cl_update_cleanpkg_set',
                         'builder.cl_builder_check_automagic_set',
@@ -217,7 +217,7 @@ class Wsdl(WsdlBase):
                         'update.cl_update_eixupdate_force',
                         'cl_builder_rebuild_changed_set',
                         'cl_builder_rebuilt_binaries_set',
-                        'update.cl_update_skip_rb_set',
+                        'update.cl_update_revdep_rebuild_set',
                         'update.cl_update_onedepth_set',
                         'update.cl_update_cleanpkg_set',
                         'builder.cl_builder_check_automagic_set',
@@ -243,7 +243,7 @@ class Wsdl(WsdlBase):
                         'update.cl_update_eixupdate_force',
                         'cl_builder_rebuild_changed_set',
                         'cl_builder_rebuilt_binaries_set',
-                        'update.cl_update_skip_rb_set',
+                        'update.cl_update_revdep_rebuild_set',
                         'update.cl_update_onedepth_set',
                         'update.cl_update_cleanpkg_set',
                         'builder.cl_builder_check_automagic_set',
